@@ -33,20 +33,12 @@ main(int argc, char** argv)
     Grs::Main app(argc, argv);
 
     Grs::GridImage image;
-    Gtk::Window graphwin;
-    graphwin.set_default_size(200, 200);
-    graphwin.set_title("graph");
     Grs::GraphCanvas graph(1);
-    graphwin.add(graph);
 
-    Gtk::Window win;
-    win.set_title("graphtest");
     Grs::ButtonBox box;
     box.add_func("step", bind(&make_image, ref(graph[0]), ref(image)));
-    box.add_window(graphwin);
-    win.add(box);
-    win.show_all();
+    box.add_window("graph", graph);
 
-    Grs::Main::run(win);
+    app.run("graphtest", box);
     return 0;
 }
