@@ -37,9 +37,9 @@ ButtonBox::~ButtonBox()
 }
 
 void
-ButtonBox::add_window(Gtk::Window& window)
+ButtonBox::add_window(char const* name, Gtk::Widget& widget)
 {
-    WindowButton* button = manage(new WindowButton(window));
+    WindowButton* button = manage(new WindowButton(name, widget));
     pack_start(*button, Gtk::PACK_SHRINK);
 }
 
