@@ -34,7 +34,7 @@ public:
 
     virtual ~ButtonBox();
 
-    void add_window(Gtk::Window& window);
+    void add_window(const char* name, Gtk::Widget& widget);
 
     void add_func(const char* name, const sigc::slot<void>& func);
 
