@@ -23,14 +23,13 @@
 
 #include <gtkmm/button.h>
 #include <gtkmm/fileselection.h>
-#include <boost/function.hpp>
 
 namespace Grs {
 
 class FileButton : public Gtk::Button
 {
 public:
-    FileButton(const char* name, const boost::function<bool(const char*)>& f);
+    FileButton(const char* name, const sigc::slot<bool, const char*>& f);
     virtual ~FileButton();
 
 protected:
@@ -39,7 +38,7 @@ protected:
 
 private:
     Gtk::FileSelection m_file;
-    boost::function<bool(const char*)> m_func;
+    sigc::slot<bool, const char*> m_func;
 };
 
 }
