@@ -22,7 +22,7 @@
 
 namespace Grs {
 
-FuncButton::FuncButton(const char* name, const boost::function<void()>& func)
+FuncButton::FuncButton(const char* name, const sigc::slot<void>& func)
     : Gtk::Button(name), m_func(func)
 {
 }
