@@ -22,21 +22,20 @@
 #define GRS_FUNCBUTTON_H
 
 #include <gtkmm/button.h>
-#include <boost/function.hpp>
 
 namespace Grs {
 
 class FuncButton : public Gtk::Button
 {
 public:
-    FuncButton(const char* name, const boost::function<void()>& func);
+    FuncButton(const char* name, const sigc::slot<void>& func);
     virtual ~FuncButton();
 
 protected:
     virtual void on_clicked();
 
 private:
-    boost::function<void()> m_func;
+    sigc::slot<void> m_func;
 };
 
 }
