@@ -39,7 +39,7 @@ public:
     const Grs::Graph& operator[](int index) const;
 
 protected:
-    virtual void on_size_allocate(GtkAllocation* rect);
+    virtual void on_size_allocate(Gtk::Allocation& rect);
 
 private:
     std::vector<Grs::Graph*> m_graph;
