@@ -19,6 +19,7 @@
  */
 
 #include "main.h"
+#include <gtkmm/window.h>
 #include <libgnomecanvasmm/init.h>
 
 namespace Grs {
@@ -33,4 +34,14 @@ Main::~Main()
 {
 }
 
+void
+Main::run(char const* name, Gtk::Widget& widget)
+{
+    Gtk::Window win;
+    win.set_title(name);
+    win.add(widget);
+    win.show_all();
+    Gtk::Main::run(win);
+}
+
 }
