@@ -30,6 +30,9 @@ class Main : public Gtk::Main
 public:
     Main(int argc, char** argv);
     virtual ~Main();
+
+    using Gtk::Main::run;
+    static void run(char const* name, Gtk::Widget& widget);
 };
 
 }
