@@ -22,14 +22,13 @@
 #define GRS_THREADBUTTON_H
 
 #include <gtkmm/togglebutton.h>
-#include <boost/function.hpp>
 
 namespace Grs {
 
 class ThreadButton : public Gtk::ToggleButton
 {
 public:
-    ThreadButton(const char* name, const boost::function<bool()>& run);
+    ThreadButton(const char* name, const sigc::slot<bool>& run);
     virtual ~ThreadButton();
 
     void start();
@@ -40,8 +39,8 @@ protected:
 
 private:
     Glib::ustring m_name;
-    boost::function<bool()> m_run;
-    SigC::Connection m_connection;
+    sigc::slot<bool> m_run;
+    sigc::connection m_connection;
 
     bool run();
 };
