@@ -22,7 +22,6 @@
 #define GRS_TOGGLEBUTTON_H
 
 #include <gtkmm/togglebutton.h>
-#include <boost/function.hpp>
 #include <grs/property.h>
 
 namespace Grs {
@@ -32,17 +31,16 @@ class ToggleButton : public Gtk::ToggleButton
 public:
     ToggleButton(const char* name, Property<bool>& flag);
     ToggleButton(const char* name,
-            const boost::function<void()>& start,
-            const boost::function<void()>& stop);
-    ToggleButton(const char* name, const boost::function<void(bool)>& func);
+            const sigc::slot<void>& start, const sigc::slot<void>& stop);
+    ToggleButton(const char* name, const sigc::slot<void, bool>& func);
     virtual ~ToggleButton();
 
 protected:
     virtual void on_toggled();
 
 private:
-    boost::function<void()> m_start;
-    boost::function<void()> m_stop;
+    sigc::slot<void> m_start;
+    sigc::slot<void> m_stop;
 };
 
 }
