@@ -24,10 +24,6 @@
 #include <gtkmm/label.h>
 #include <gtkmm/frame.h>
 
-#include <boost/bind.hpp>
-using boost::bind;
-using boost::ref;
-
 namespace Grs {
 
 ValueList::ValueList(int digits)
@@ -80,7 +76,7 @@ ValueList::add_property(Property<double>& property, int digits, bool writable)
     attach(*frame, 2, 3, property_n_columns()-1, property_n_columns());
     entry->modify_font(get_modifier_style()->get_font());
 
-    property.connect(boost::bind(&EntryReal::set_value, entry, _1));
+    property.connect(sigc::group(sigc::mem_fun(entry, &EntryReal::set_value), sigc::_1));
 }
 
 void
@@ -101,7 +97,7 @@ ValueList::add_property(Property<int>& property, bool writable)
     attach(*frame, 2, 3, property_n_columns()-1, property_n_columns());
     entry->modify_font(get_modifier_style()->get_font());
 
-    property.connect(boost::bind(&EntryInt::set_value, entry, _1));
+    property.connect(sigc::group(sigc::mem_fun(entry, &EntryInt::set_value), sigc::_1));
 }
 
 void
@@ -142,13 +138,14 @@ operator<<(ValueList& list, Grs::Property<int>& property)
 ValueListManip
 set_digits(int digits)
 {
-    return boost::bind(&ValueList::set_default_digits, _1, digits);
+    return sigc::group(sigc::mem_fun(&ValueList::set_default_digits),
+            sigc::_1, digits);
 }
 
 const ValueListManip rw =
-    boost::bind(&ValueList::set_default_writable, _1, true);
+    sigc::group(sigc::mem_fun(&ValueList::set_default_writable), sigc::_1, true);
 
 const ValueListManip ro =
-    boost::bind(&ValueList::set_default_writable, _1, false);
+    sigc::group(sigc::mem_fun(&ValueList::set_default_writable), sigc::_1, false);
 
 }
