@@ -21,7 +21,6 @@
 #ifndef GRS_VALUELIST_H
 #define GRS_VALUELIST_H
 
-#include <boost/function.hpp>
 #include <gtkmm/table.h>
 #include <gtkmm/window.h>
 #include <grs/property.h>
@@ -49,7 +48,7 @@ private:
     void add_label_(const Glib::ustring& name);
 };
 
-typedef boost::function<void(ValueList& list)> ValueListManip;
+typedef sigc::slot<void, ValueList&> ValueListManip;
 ValueList& operator<<(ValueList& list, const ValueListManip& manip);
 ValueList& operator<<(ValueList& list, Property<double>& property);
 ValueList& operator<<(ValueList& list, Property<int>& property);
