@@ -22,10 +22,13 @@
 
 namespace Grs {
 
-WindowButton::WindowButton(Gtk::Window& win)
-    : Gtk::ToggleButton(win.get_title()), m_win(win)
+WindowButton::WindowButton(char const* name, Gtk::Widget& widget)
+    : Gtk::ToggleButton(name), m_win()
 {
-    win.signal_hide().connect(sigc::bind(sigc::mem_fun(*this, &Gtk::ToggleButton::set_active), false));
+    m_win.set_title(name);
+    m_win.add(widget);
+    m_win.signal_hide().connect(sigc::bind(
+                sigc::mem_fun(*this, &Gtk::ToggleButton::set_active), false));
 }
 
 WindowButton::~WindowButton()
