@@ -29,14 +29,14 @@ namespace Grs {
 class WindowButton : public Gtk::ToggleButton
 {
 public:
-    WindowButton(Gtk::Window& win);
+    WindowButton(char const* name, Gtk::Widget& widget);
     virtual ~WindowButton();
 
 protected:
     virtual void on_toggled();
 
 private:
-    Gtk::Window& m_win;
+    Gtk::Window m_win;
 };
 
 }
